@@ -27,6 +27,11 @@ our $VERSION = '0.02' ;
 
 #-------------------------------------------------------------------------------
 
+use Data::TreeDumper ;
+$Data::TreeDumper::Useascii = 0 ;
+
+#-------------------------------------------------------------------------------
+
 sub DumpDependentStack
 {
 my $ss = shift ;
@@ -91,12 +96,6 @@ $Devel::Size::warn = 0 ;
 $use_devel_size = 1 ;
 EOE
 
-eval <<'EOE' ;
-use Data::TreeDumper ;
-$Data::TreeDumper::Useascii = 0 ;
-$use_data_treedumper = 1 ;
-EOE
-
 my $dump ;
 
 $dump .= '-' x 60 . "\n" ;
@@ -116,129 +115,108 @@ $dump .= "\n" ;
 
 if($display_setup)
 	{
-	if($use_data_treedumper)
-		{
-		my $NoData = sub
-				{
-				my $s = shift ;
-				
-				if('Spreadsheet::Perl' eq ref $s)
-					{
-					return('HASH', undef, sort grep {! /CELLS/} keys %$s) ;
-					}
-					
-				return(Data::TreeDumper::DefaultNodesToDisplay($s)) ;
-				} ;
-		
-		$dump .= DumpTree($ss, 'Setup:', FILTER => $NoData, DISPLAY_ADDRESS => 0, %$dtd_setup) ;
-		}
-	else
-		{
-		for my $key (sort keys %$ss)
+	my $NoData = sub
 			{
-			next if $key =~ /^CELLS$/ ;
+			my $s = shift ;
 			
-			$dump .= Data::Dumper->Dump([$ss->{$key}], [$key]);
-			}
-		}
+			if('Spreadsheet::Perl' eq ref $s)
+				{
+				return('HASH', undef, sort grep {! /CELLS/} keys %$s) ;
+				}
+				
+			return(Data::TreeDumper::DefaultNodesToDisplay($s)) ;
+			} ;
+	
+	$dump .= DumpTree($ss, 'Setup:', FILTER => $NoData, DISPLAY_ADDRESS => 0, %$dtd_setup) ;
 	}
 	
 $dump .= "\n" ;
 
-if($use_data_treedumper)
+my %cell_filter ;
+
+if(defined $address_list)
 	{
-	my %cell_filter ;
+	my %cells_to_display ;
+	@cells_to_display{$ss->GetAddressList(@$address_list)} = undef ;
 	
-	if(defined $address_list)
-		{
-		my %cells_to_display ;
-		@cells_to_display{$ss->GetAddressList(@$address_list)} = undef ;
-		
-		my $CellPruner = sub
-					{
-					my $s = shift ;
-					if('HASH' eq ref $s)
-						{
-						return('HASH', $s, , SortCells(grep {exists $cells_to_display{$_};} keys %$s)); 
-						}
-						
-					die "this filter is to be used on hashes!." ;
-					} ;
-					
-		%cell_filter= (LEVEL_FILTERS => {0 => $CellPruner}) ;
-		}
-	else
-		{
-		my $CellSorter= sub
-					{
-					my $s = shift ;
-					if('HASH' eq ref $s)
-						{
-						return('HASH', $s, SortCells(keys %$s)) ;
-						}
-						
-					die "this filter is to be used on hashes!." ;
-					} ;
-					
-		%cell_filter= (LEVEL_FILTERS => {0 => $CellSorter}) ;
-		}
-		
-	my $NoDependentData = sub
+	my $CellPruner = sub
 				{
 				my $s = shift ;
-				
 				if('HASH' eq ref $s)
 					{
-					my $is_dependent_hash = grep {/^Spreadsheet::Perl=HASH\(0x[0-9a-z]+\), [A-Z]/} keys %$s ;
-					
-					if($is_dependent_hash)
-						{
-						my @dependents ;
-						my @dependents_formulas ;
-						
-						for my $dependent (keys %$s)
-							{
-							my ($spreadsheet, $cell, $name) = @{$s->{$dependent}{CELLS}} ;
-							push @dependents, "$name!$cell" ;
-							
-							if($ss->{DEBUG}{DEPENDENT})
-								{
-								push @dependents_formulas, "$s->{$dependent}{FORMULA}[0] [$s->{$dependent}{COUNT}]" ;
-								}
-							else
-								{
-								push @dependents_formulas, 1 ;
-								}
-							}
-							
-						return ('ARRAY', \@dependents_formulas, map{[$_, $dependents[$_]]} 0 .. $#dependents ) ;
-						}
-					else
-						{
-						return(Data::TreeDumper::DefaultNodesToDisplay($s)) ;
-						}
+					return('HASH', $s, , SortCells(grep {exists $cells_to_display{$_};} keys %$s)); 
 					}
 					
-				return(Data::TreeDumper::DefaultNodesToDisplay($s)) ;
+				die "this filter is to be used on hashes!." ;
 				} ;
 				
-	my $tdt_dump .= DumpTree
-			(
-			  $ss->{CELLS}
-			, "Cells (" . scalar(keys %{$ss->{CELLS}}) . "):"
-			, DISPLAY_ADDRESS        => 0
-			, FILTER                 => $NoDependentData
-			, %cell_filter
-			, %$dtd_setup
-			) ;
-			
-	$dump .= $tdt_dump ;
+	%cell_filter= (LEVEL_FILTERS => {0 => $CellPruner}) ;
 	}
 else
 	{
-	$dump .= Data::Dumper->Dump([$ss->{CELLS}], ['Cells']) ;
+	my $CellSorter= sub
+				{
+				my $s = shift ;
+				if('HASH' eq ref $s)
+					{
+					return('HASH', $s, SortCells(keys %$s)) ;
+					}
+					
+				die "this filter is to be used on hashes!." ;
+				} ;
+				
+	%cell_filter= (LEVEL_FILTERS => {0 => $CellSorter}) ;
 	}
 	
+my $NoDependentData = sub
+			{
+			my $s = shift ;
+			
+			if('HASH' eq ref $s)
+				{
+				my $is_dependent_hash = grep {/^Spreadsheet::Perl=HASH\(0x[0-9a-z]+\), [A-Z]/} keys %$s ;
+				
+				if($is_dependent_hash)
+					{
+					my @dependents ;
+					my @dependents_formulas ;
+					
+					for my $dependent (keys %$s)
+						{
+						my ($spreadsheet, $cell, $name) = @{$s->{$dependent}{CELLS}} ;
+						push @dependents, "$name!$cell" ;
+						
+						if($ss->{DEBUG}{DEPENDENT})
+							{
+							push @dependents_formulas, "$s->{$dependent}{FORMULA}[0] [$s->{$dependent}{COUNT}]" ;
+							}
+						else
+							{
+							push @dependents_formulas, 1 ;
+							}
+						}
+						
+					return ('ARRAY', \@dependents_formulas, map{[$_, $dependents[$_]]} 0 .. $#dependents ) ;
+					}
+				else
+					{
+					return(Data::TreeDumper::DefaultNodesToDisplay($s)) ;
+					}
+				}
+				
+			return(Data::TreeDumper::DefaultNodesToDisplay($s)) ;
+			} ;
+			
+$dump .= DumpTree
+		(
+		  $ss->{CELLS}
+		, "Cells (" . scalar(keys %{$ss->{CELLS}}) . "):"
+		, DISPLAY_ADDRESS        => 0
+		, FILTER                 => $NoDependentData
+		, %cell_filter
+		, %$dtd_setup
+		) ;
+		
 $dump .= "\n$ss " ;
 
 if(defined $ss->{NAME})
@@ -266,7 +244,7 @@ return( "Cells to update: " . (join " - ", $ss->GetCellsToUpdate()) . "\n") ;
 __END__
 =head1 NAME
 
-Spreadsheet::Perl::Devel- Development support for Spreadsheet::Perl
+Spreadsheet::Perl::Devel - Development support for Spreadsheet::Perl
 
 =head1 SYNOPSIS
 
